@@ -16,7 +16,7 @@ use POE::Component::IRC::Plugin::Whois;
 use Socket;
 use base qw(POE::Component::Pluggable);
 
-our $VERSION = '6.09_11';
+our $VERSION = '6.11_01';
 our ($GOT_SSL, $GOT_CLIENT_DNS, $GOT_SOCKET6, $GOT_ZLIB);
 
 BEGIN {
@@ -374,10 +374,17 @@ sub _sock_up {
     # Remember what IP address we're connected through, for multihomed boxes.
     my $localaddr;
     if ($GOT_SOCKET6) {
-        eval { $localaddr = (unpack_sockaddr_in6( getsockname $socket ))[1] };
+        eval { 
+                $localaddr = (unpack_sockaddr_in6( getsockname $socket ))[1];
+                $localaddr = inet_ntop( AF_INET6, $localaddr );
+        };
+    }
+
+    if ( !$localaddr ) {
+        $localaddr = (unpack_sockaddr_in( getsockname $socket ))[1];
+        $localaddr = inet_ntoa($localaddr);
     }
 
-    $localaddr = (unpack_sockaddr_in( getsockname $socket ))[1] if !$localaddr;
     $self->{localaddr} = $localaddr;
 
     if ( $self->{socks_proxy} ) {
